@@ -1,16 +1,19 @@
 import asyncio
 
+from windyquery import DB
 
 loop = asyncio.get_event_loop()
 
-def test_group_by(schema, db):
+
+def test_group_by(db: DB):
     async def create_table():
-        return await schema.create('cards_tmp',
-            schema.column('id').serial().primary_key(),
-            schema.column('board_id').integer().nullable(False)
+        return await db.schema('TABLE cards_tmp').create(
+            'id serial PRIMARY KEY',
+            'board_id integer not null',
         )
+
     async def drop_table():
-        return await schema.drop('cards_tmp')
+        return await db.schema('TABLE cards_tmp').drop()
 
     loop.run_until_complete(create_table())
     loop.run_until_complete(db.table('cards_tmp').insert(
@@ -18,7 +21,8 @@ def test_group_by(schema, db):
         {'board_id': 1},
         {'board_id': 2},
     ))
-    rows = loop.run_until_complete(db.table('cards_tmp').select('board_id').group_by('board_id'))
+    rows = loop.run_until_complete(
+        db.table('cards_tmp').select('board_id').group_by('board_id'))
     loop.run_until_complete(drop_table())
     assert len(rows) == 2
     rows.sort(key=lambda x: x['board_id'])
